##
#
# Ping pong application for ESBs
#
# Copyright 2005-2007, Freie Universitaet Berlin. All rights reserved.
# Please refer to the COPYING file for detailed licensing information.
#
# Contributors: Georg Wittenburg
#
##

source scatterweb_esb.tcl

# Number of mobile nodes
set val(nn)	20

# Size of topography (m)
set val(x)	600
set val(y)	450

# Simulation duration (s)
set simulation_duration 10.0

source ns-2_simulation_header.tcl

# Create, initialize and connect nodes and agents
for {set i 0} {$i < $val(nn)} {incr i} {
	# Create mobile node
	set node_($i) [$ns_ node]
	# Set initial position
	$node_($i) set X_ [$rng_ uniform 0 $val(x)]
	$node_($i) set Y_ [$rng_ uniform 0 $val(y)]
	$node_($i) set Z_ 0
	# Disable random motion
	$node_($i) random-motion 0
	# Register node.
	$god_ new_node $node_($i)
	$ns_ initial_node_pos $node_($i) 10

	# Create ScatterWeb ESB sensor node with empty UserApp
	set agent_($i) [new Agent/MessagePassing/ScatterWeb/EmptyESB]
	# Adjust packet size for ScatterWeb
	$agent_($i) set packetSize_ 1024
	# Set agent not to provide call traces
	$agent_($i) set strace_ false
	# Start mobile nodes
	$ns_ at 0 "$node_($i) start";
	# Load the EEPROM image into the agent
	$ns_ at 0.01 "$agent_($i) loadEEPROM eeprom.bin";
	# Set the ID of the ScatterWeb node
	$ns_ at 0.02 "$agent_($i) setNodeID [$node_($i) id]";
	# Initialize ScatterWeb firmware as soon as the simulation starts
	$ns_ at [$rng_ uniform 0.03 0.04] "$agent_($i) initFirmware";
	# Stop the agent when the simulation ends
	$ns_ at $simulation_duration "$agent_($i) stop";
	# Attach the ScatterWeb agent to the mobile node
	$node_($i) attach $agent_($i)
}

# Activate nodes
set activation_interval 0.1
for {set t $activation_interval} {$t < [expr $simulation_duration - 0.1]} {set t [expr $t + $activation_interval]} {
	set id [expr round([$rng_ uniform 0 [expr $val(nn) - 1]])]
	$ns_ at [$rng_ uniform $t [expr $t + 0.01]] "$agent_($id) pushButton";
}

source ns-2_simulation_footer.tcl
